#
# spec file for package ck
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   0
%define libname libck%{sover}
Name:           ck
Version:        0.7.2
Release:        1.2
Summary:        Concurrency Kit
License:        Apache-2.0 AND BSD-2-Clause
URL:            http://concurrencykit.org/
Source:         https://github.com/concurrencykit/ck/archive/refs/tags/%{version}.tar.gz#/ck-%{version}.tar.gz
BuildRequires:  pkgconfig

%description
Concurrency primitives, safe memory reclamation mechanisms and non-blocking
data structures for the research, design and implementation of high performance
concurrent systems.

%package -n %{libname}
Summary:        Shared library for Concurrency Kit

%description -n %{libname}
Concurrency primitives, safe memory reclamation mechanisms and non-blocking
data structures for the research, design and implementation of high performance
concurrent systems.

This package holds the shared library.

%package devel
Summary:        Development files for Concurrency Kit
Requires:       %{libname} = %{version}

%description devel
Concurrency primitives, safe memory reclamation mechanisms and non-blocking
data structures for the research, design and implementation of high performance
concurrent systems.

This package holds the development files.

%prep
%autosetup

%build
# not a normal autotool configure, can't use configure macro
export CFLAGS="%{optflags}"
# not autotools configure
./configure                       \
  --includedir=%{_includedir}/ck/ \
  --libdir=%{_libdir}             \
  --mandir=%{_mandir}             \
  --prefix=%{_prefix}             \
  --cores=%{jobs}

# The following options will affect generated code.
#  --enable-pointer-packing Assumes address encoding is subset of pointer range
#  --enable-rtm             Enable restricted transactional memory (power, x86_64)
#  --enable-lse             Enable large system extensions (arm64)
#  --memory-model=N         Specify memory model (currently tso, pso or rmo)
#  --vma-bits=N             Specify valid number of VMA bits
#  --platform=N             Force the platform type, instead of relying on autodetection
#  --use-cc-builtins        Use the compiler atomic bultin functions, instead of the CK implementation
#  --disable-double         Don't generate any of the functions using the "double" type
# The following options affect regression testing.
#   --cores=N                Specify number of cores available on target machine

%make_build

%install
%make_install
rm -rv %{buildroot}%{_libdir}/libck.a

%check
%make_build check

%ldconfig_scriptlets -n %{libname}

%files -n %{libname}
%license LICENSE
%{_libdir}/libck.so.%{sover}*

%files devel
%{_mandir}/man3/ck*
%{_mandir}/man3/CK*
%{_libdir}/libck.so
%{_includedir}/ck/
%{_libdir}/pkgconfig/ck.pc

%changelog
* Tue Jul 30 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.7.2:
  * This release adds support for riscv, as provided by Mitchell Horne, as well a miscellaneous bug fixes and improvments
- Enable building for all architectures
* Sun Jul  4 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.7.1
  * Add s390x support
  * ck_hs: add convenience hash function wrapper ck_hs_hash
  * ck_backoff: avoid dead store to ceiling
  * ck_ring: add two new utility functions for persistent rings
  * ck_sequence: reduce thread count to account for writer
  * ck_queue: fix logic inversion in CK_STAILQ_CONCAT
  * ck_epoch: allow record sharing and reentrancy for write-side operations
- Drop upstream merged patches: ck-fix-gettid-glibc-clash.patch,
  ck-fix-j1.patch
* Tue Oct 29 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix symbol name clash between glibc 2.30 and ck, add
  ck-fix-gettid-glibc-clash.patch
- Reenable tests again
* Wed Oct  9 2019 Martin Pluskal <mpluskal@suse.com>
- Disable tests as they fail with gcc9
* Tue Jun 18 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Add ck-fix-j1.patch to fix build with -j1
* Wed Apr 18 2018 mpluskal@suse.com
- Small packaging changes
* Wed May 17 2017 mpluskal@suse.com
- Add _constraints to avoid test failures
* Wed Apr 26 2017 mpluskal@suse.com
- Disable s390 building as it is not supported architecture
* Wed Apr 26 2017 mpluskal@suse.com
- Update to version 0.6.0
* Wed Jan 27 2016 mrueckert@suse.de
- include license file
- explain why we don't use the configure macro
* Mon Jan 25 2016 mrueckert@suse.de
- initial package
